@@ -1,5 +1,6 @@
 import email
 import sys
+from email.message import Message
 from typing import Dict, IO, List, Optional
 
 if sys.version_info < (3, 8):
@@ -7,7 +8,7 @@ if sys.version_info < (3, 8):
 else:
     from typing import Final
 
-from unstructured.cleaners.core import replace_mime_encodings
+from unstructured.cleaners.core import replace_mime_encodings, clean_extra_whitespace
 from unstructured.documents.elements import Element, Text
 from unstructured.partition.html import partition_html
 
@@ -15,6 +16,36 @@ from unstructured.partition.html import partition_html
 VALID_CONTENT_SOURCES: Final[List[str]] = ["text/html"]
 
 
+def extract_attachment_info(
+    message: Message, output_dir: Optional[str] = None
+) -> List[Dict[str, str]]:
+    list_attachments = []
+    attachment_info = {}
+    for part in message.walk():
+        if "content-disposition" in part:
+            cdisp = part["content-disposition"].split(";")
+            cdisp = [clean_extra_whitespace(item) for item in cdisp]
+
+            for item in cdisp:
+                if item.lower() == "attachment":
+                    continue
+                key, value = item.split("=")
+                key = clean_extra_whitespace(key.replace('"', ""))
+                value = clean_extra_whitespace(value.replace('"', ""))
+                attachment_info[clean_extra_whitespace(key)] = clean_extra_whitespace(value)
+            attachment_info["payload"] = part.get_payload(decode=True)
+            list_attachments.append(attachment_info)
+
+            for attachment in list_attachments:
+                if output_dir:
+                    filename = output_dir + "/" + attachment["filename"]
+                    with open(filename, "wb") as f:
+                        # mypy wants to just us `w` when opening the file but this
+                        # causes an error since the payloads are bytes not str
+                        f.write(attachment["payload"])  # type: ignore
+    return list_attachments
+
+
 def partition_email(
     filename: Optional[str] = None,
     file: Optional[IO] = None,
